@@ -1,4 +1,4 @@
-function.Create_Plots <- function(rv){
+function.Create_Plots <- function(Predefined_lists, rv){
   # Lists
   plan <- {cbind.data.frame(
     analysis_number = paste0("AN", formatC((length(rv$plan) + 1), width = 4, format = "d", flag = 0)),
@@ -43,7 +43,7 @@ function.Create_Plots <- function(rv){
     'rv$entry[[4]] <- ', ifelse(length(rv$entry[[4]]) > 1,
                                 paste0('c("', paste0(rv$entry[[4]], collapse = '", "'), '")'),
                                 paste0('"',rv$entry[[3]],'"')), '\n',
-    'AN', formatC((length(rv$plan) + 1), width = 4, format = "d", flag = 0), '_results <- function.',rv$first_menu_choice,'(rv)', '\n',
+    'AN', formatC((length(rv$plan) + 1), width = 4, format = "d", flag = 0), '_results <- function.',rv$first_menu_choice,'(Predefined_lists, rv)', '\n',
     if(length(rv$plan) == 0){
       'if (TRUE %in% (AN0001_results$plots_list != "")) {invisible(file.rename(AN0001_results$plots_list, paste0(AN0001_results$plots_list,"_copy")))}
 '
