@@ -1,4 +1,4 @@
-function.Make_Conclusions_Effect_size <- function(rv){
+function.Make_Conclusions_Effect_size <- function(Predefined_lists, rv){
   # Lists
   plan <- {cbind.data.frame(
     analysis_number = paste0("AN", formatC((length(rv$plan) + 1), width = 4, format = "d", flag = 0)),
@@ -51,7 +51,7 @@ function.Make_Conclusions_Effect_size <- function(rv){
     'rv$entry[[10]] <- ', rv$entry[[10]], '\n',
     'rv$entry[[11]] <- "', rv$entry[[11]], '"\n',
     'rv$entry[[12]] <- "', rv$entry[[12]], '"\n',
-    'AN', formatC((length(rv$plan) + 1), width = 4, format = "d", flag = 0), '_results <- function.',rv$first_menu_choice,'(rv)', '\n',
+    'AN', formatC((length(rv$plan) + 1), width = 4, format = "d", flag = 0), '_results <- function.',rv$first_menu_choice,'(Predefined_lists, rv)', '\n',
     if(length(rv$plan) == 0){
       'if (TRUE %in% (AN0001_results$plots_list != "")) {invisible(file.rename(AN0001_results$plots_list, paste0(AN0001_results$plots_list,"_copy")))}
 '
