@@ -1,4 +1,4 @@
-function.Sample_Size_Calculations_Primary <- function(rv){
+function.Sample_Size_Calculations_Primary <- function(Predefined_lists, rv){
   # Lists
   plan <- {cbind.data.frame(
     analysis_number = paste0("AN", formatC((length(rv$plan) + 1), width = 4, format = "d", flag = 0)),
@@ -37,7 +37,7 @@ function.Sample_Size_Calculations_Primary <- function(rv){
                                 paste0('c("', paste0(rv$entry[[2]], collapse = '", "'), '")'),
                                 paste0('"',rv$entry[[2]],'"')), '\n',
     'rv$entry[[3]] <- ', rv$entry[[3]], '\n',
-    'AN', formatC((length(rv$plan) + 1), width = 4, format = "d", flag = 0), '_results <- function.',rv$first_menu_choice,'(rv)', '\n',
+    'AN', formatC((length(rv$plan) + 1), width = 4, format = "d", flag = 0), '_results <- function.',rv$first_menu_choice,'(Predefined_lists, rv)', '\n',
     if(length(rv$plan) == 0){
       'if (TRUE %in% (AN0001_results$plots_list != "")) {invisible(file.rename(AN0001_results$plots_list, paste0(AN0001_results$plots_list,"_copy")))}
 '
